

!!! Listing 1

import java.io.File;
import java.io.FileReader;
import java.io.PrintStream;
import org.xml.sax.AttributeList;
import org.xml.sax.HandlerBase;
import org.xml.sax.InputSource;
import org.xml.sax.Parser;
import org.xml.sax.SAXException;

public class HTMLConverterSAX extends HandlerBase {
  PrintStream out;

  public HTMLConverterSAX(PrintStream out) {
    this.out = out;
  }

  public void startDocument() throws SAXException {
    out.println("<HTML>\n<HEAD>\n<TITLE>Telefonliste</TITLE>\n</HEAD>");
    out.println("<BODY BGCOLOR=\"#ffffff\">\n");
  }

  public void endDocument() throws SAXException {
    out.println("</BODY>\n</HTML>\n");
  }

  public void startElement(java.lang.String name, AttributeList atts) 
    throws SAXException {
    if (name.equals("MITARBEITER")) {
      out.print("<TR>");
    } else if (name.equals("TELEFONLISTE")) {
      out.println("<H2>Telefonliste</H2>\n<TABLE>");
    } else {
      out.print("<TD>");
    }
  }

  public void endElement(java.lang.String name) throws SAXException {
    if (name.equals("MITARBEITER")) {
      out.println("</TR>");
    } else if (name.equals("TELEFONLISTE")) {
      out.println("</TABLE>");
    }
  }

  public void characters(char[] ch, int start, int length) 
    throws SAXException {
    out.print(unicode2HTML(ch, start, length));
  }

  String unicode2HTML(char[] ch, int start, int length) {
    StringBuffer s = new StringBuffer();
    for (int i = start; i < start+length; i++) {
      switch(ch[i]) {
        case '': s.append("&auml;"); break;
        case '': s.append("&ouml;"); break;
        case '': s.append("&uuml;"); break;
        case '': s.append("&szlig;"); break;
        case '\u00e9': s.append("&eacute;"); break;
      default: s.append(ch[i]);
      }
    }
    return s.toString();
  }

  public static void main(String[] args) 
         throws Exception {
    Parser parser = new com.sun.xml.parser.Parser();
    parser.setDocumentHandler(new HTMLConverterSAX(System.out));
    InputSource source = new InputSource(new FileReader(args[0]));
    source.setSystemId("file:"+new File(args[0]).getAbsolutePath());
    parser.parse(source);
  }

}


!!! Listing 2

<!ELEMENT TELEFONLISTE (MITARBEITER*)>
<!ELEMENT MITARBEITER (NAME,EMAIL,TEL)>

<!ELEMENT NAME (#PCDATA)>
<!ELEMENT EMAIL (#PCDATA)>
<!ELEMENT TEL (#PCDATA)>


!!! Listing 3

<?xml version="1.0" standalone='no'?>
<!DOCTYPE TELEFONLISTE SYSTEM "telefon.dtd">

<TELEFONLISTE>
<MITARBEITER>
  <NAME>Henning Behme</NAME>
  <EMAIL>hb@ix.heise.de</EMAIL>
  <TEL>-374</TEL>
</MITARBEITER>

<MITARBEITER>
  <NAME>Jrgen Seeger</NAME>
  <EMAIL>js@ix.heise.de</EMAIL>
  <TEL>-386</TEL>
</MITARBEITER>

<MITARBEITER>
  <NAME>Andr&#xe9; von Raison</NAME>
  <EMAIL>avr@ix.heise.de</EMAIL>
  <TEL>-377</TEL>
</MITARBEITER>
</TELEFONLISTE>


!!! Listing 4 

import java.io.FileReader;
import java.io.PrintStream;
import org.w3c.dom.Document;
import org.w3c.dom.Node;
import com.ibm.xml.parser.NonRecursivePreorderTreeTraversal;
import com.ibm.xml.parser.Parser;
import com.ibm.xml.parser.TXDocument;
import com.ibm.xml.parser.TXElement;
import com.ibm.xml.parser.NOOPVisitor;
import com.ibm.xml.parser.TXText;

public class HTMLConverterIBM extends NOOPVisitor {
  PrintStream out;

  public HTMLConverterIBM(PrintStream out) {
    this.out = out;
  }

  // Kopf und Fuss analog SAX-Beispiel

  public void visitElementPre(TXElement element) {
    String name = element.getName();
    if (name.equals("MITARBEITER")) {
      out.print("<TR>");
    } else if (name.equals("TELEFONLISTE")) {
      out.println("<H2>Telefonliste</H2>\n<TABLE>");
    } else if (name.equals("EMAIL")) {       
      Node child; String email;
      // Zugriff auf Tochterknoten
      child = element.getFirstChild();
      email = ((TXText)child).getText();
      out.print("<TD><A HREF=\"mailto:"+
                email+"\">");
    } else {
      out.print("<TD>");
    }
  }

  public void visitElementPost(TXElement element) {
    String name = element.getName();
    if (name.equals("MITARBEITER")) {
      out.println("</TR>");
    } else if (name.equals("TELEFONLISTE")) {
      out.println("</TABLE>");
    } else {
      if (name.equals("EMAIL")) {
        out.print("</A>");
      }
      out.print("</TD>");
    }
  }

  // Text-Ausgabe analog SAX-Beispiel

  public static void main(String[] args) throws Exception {
    Parser parser = new Parser("");
    NonRecursivePreorderTreeTraversal traversal;    
    HTMLConverterIBM converter;
    converter = new HTMLConverterIBM(System.out);
    traversal = new NonRecursivePreorderTreeTraversal(converter);
    Document document = parser.readStream(new FileReader(args[0]));
    traversal.traverse(document);
    
  }


}


!!! Listing 5

import com.ibm.xml.parser.TXElement;

public class Mitarbeiter extends TXElement {

  String name, email, phone;
  
  public Mitarbeiter() {
    super("MITARBEITER");
  }

  public String getName() { return name; }
  public String getEmail() { return email; }
  public String getPhone() { return phone; }

  public void setName(String name) { this.name = name; }
  public void setEmail(String email) { this.email = email; }
  public void setPhone(String phone) { this.phone = phone; }

}


import com.ibm.xml.parser.TXDocument;
import com.ibm.xml.parser.TXText;
import org.w3c.dom.Element;
import org.w3c.dom.Node;

public class BeanFactory extends TXDocument {

  public Element createElement(String tagName) {
    if (tagName.equals("MITARBEITER")) {
      Node node;
      Mitarbeiter bean;
      
      // Bean erzeugen
      bean = new Mitarbeiter();
      bean.setFactory(this);

      // Daten aus den Tochterknoten holen
      node = bean.getElementNamed("NAME").getFirstChild();
      bean.setName(((TXText)node).getText());
      node = bean.getElementNamed("EMAIL").getFirstChild();
      bean.setEmail(((TXText)node).getText());
      node = bean.getElementNamed("PHONE").getFirstChild();
      bean.setPhone(((TXText)node).getText());

      return bean;
    } else
      return super.createElement(tagName);   
  }

}
